@@ -40,15 +40,16 @@ except OSError as error:
     logging.error(LOG_STRING)
 
     # tell later parts of the code not to actually use the driver
-    do_no_use_PCA_driver = True
+   
+    DO_NOT_USE_PCA_DRIVER = True
 
     PWM = ""
 except:
     print("There was an error loading the adafruit driver; loading without PCA9685.")
-    do_no_use_PCA_driver = True # tell later parts of the code not to actually use the driver
+    DO_NOT_USE_PCA_DRIVER = True # tell later parts of the code not to actually use the driver
 else:
     LOG_STRING = "PCA9685 Driver loaded)."
-    do_no_use_PCA_driver = False # tell later parts of the code to use the driver
+    DO_NOT_USE_PCA_DRIVER = False # tell later parts of the code to use the driver
     logging.error(LOG_STRING)
 
 # Configure min and max servo pulse lengths
@@ -60,7 +61,7 @@ SLEEP_COUNT = 0.05    # the amount of time to wait between pwm operations
 
 # Set frequency to 60hz, good for servos.
 try:
-    if do_no_use_PCA_driver is False:
+    if DO_NOT_USE_PCA_DRIVER is False:
         PWM.set_pwm_freq(60)
 except ValueError as error:
     LOG_STRING = "failed to set the pwm frequency:, " + error
@@ -104,21 +105,21 @@ class Leg(object):
     """
     provides a model of a limb (for either a foot or a leg)
     """
-    leg_min = 150
-    leg_max = 600
-    swingangle = 0
-    bodyangle = 0
-    stretchangle = 0
-    currentangle = 0
-    invert = False
-    leg_angle = 0
-    leg_minAngle = 0
-    leg_maxAngle = 180
+    __leg_min = 150
+    __leg_max = 600
+    __swingangle = 0
+    __bodyangle = 0
+    __stretchangle = 0
+    __currentangle = 0
+    __invert = False
+    __leg_angle = 0
+    __leg_minAngle = 0
+    __leg_maxAngle = 180
 
     def __init__(self, name, channel, leg_minangle, leg_maxangle, invert):
         # Initialises the leg object
         try:
-            if do_no_use_PCA_driver is False:
+            if DO_NOT_USE_PCA_DRIVER is False:
                 pwm = Adafruit_PCA9685.PCA9685()
         except RuntimeError as error:
             logging.warning("The servo driver failed to initialise  \
@@ -127,106 +128,140 @@ class Leg(object):
             logging.warning(error)
 
         try:
-            if do_no_use_PCA_driver is False:
+            if DO_NOT_USE_PCA_DRIVER is False:
                 pwm.set_pwm_freq(60)
         except:
             logging.warning(
                 "Failed to set the pwm frequency - did the servo driver initialize correctly?")
 
-        self.name = name
-        self.channel = channel
-        self.leg_minangle = leg_minangle
-        self.leg_maxangle = leg_maxangle
-        self.invert = invert
+        self.__name = name
+        self.__channel = channel
+        self.__leg_minangle = leg_minangle
+        self.__leg_maxangle = leg_maxangle
+        self.__invert = invert
 
-        if not self.invert:
-            self.bodyangle = self.leg_minangle
-            self.stretchangle = self.leg_maxangle
-            self.swingangle = (self.leg_minangle / 2) + self.leg_minangle
+        if not self.__invert:
+            self.__bodyangle = self.__leg_minangle
+            self.__stretchangle = self.__leg_maxangle
+            self.__swingangle = (self.__leg_minangle / 2) + self.__leg_minangle
         else:
-            self.bodyangle = self.leg_maxangle
-            self.stretchangle = self.leg_minangle
-            self.swingangle = (self.leg_maxangle - self.leg_minangle) / 2
-        self.currentangle = self.bodyangle
+            self.__bodyangle = self.__leg_maxangle
+            self.__stretchangle = self.__leg_minangle
+            self.__swingangle = (self.__leg_maxangle - self.__leg_minangle) / 2
+        self.__currentangle = self.__bodyangle
+
+    @property
+    def invert(self):
+        return self.__invert
+
+    @invert.setter
+    def invert(self,invert):
+        self.__invert = invert
 
     def setdefault(self):
+        """
+        DEPRICATED METHOD - USE .default
+        """
+        print("This method is depricated, use .default instead")
+
+    def default(self):
         """
         Sets the limb to the default angle, by dividing the maximum and
         minimum angles that were set previously
         """
-        self.setangle(self.leg_maxangle - self.leg_minangle)
-        self.currentangle = self.leg_maxangle - self.leg_minangle
+        self.angle(self.__leg_maxangle - self.__leg_minangle)
+        self.__currentangle = self.__leg_maxangle - self.__leg_minangle
 
     def setbody(self):
+        """
+        DEPRICATED METHOD - USE .body
+        """
+        print("this method is depricated, use .body instead")
+
+    def body(self):
         """
         Sets the limb to its body position.
         """
-        if not self.invert:
-            self.setangle(self.leg_minangle)
-            self.bodyangle = self.leg_minangle
+        if not self.__invert:
+            self.angle(self.__leg_minangle)
+            self.__bodyangle = self.__leg_minangle
         else:
-            self.setangle(self.leg_maxangle)
-            self.bodyangle = self.leg_maxangle
-        self.currentangle = self.bodyangle
+            self.angle(self.__leg_maxangle)
+            self.__bodyangle = self.__leg_maxangle
+        self.__currentangle = self.__bodyangle
 
-    def setstretch(self):
+    def setstrech(self):
+        """ DEPRICATED METHOD - USE .stretch """
+        print("this method is depricated, use .stretch instead")
+
+    def stretch(self):
         """
         Sets the limb to its stretch position.
         """
-        if not self.invert:
-            self.setangle(self.leg_maxangle)
-            self.stretchangle = self.leg_maxangle
+        if not self.__invert:
+            self.angle(self.__leg_maxangle)
+            self.__stretchangle = self.__leg_maxangle
         else:
-            self.setangle(self.leg_minangle)
-            self.stretchangle = self.leg_minangle
-        self.currentangle = self.stretchangle
+            self.angle(self.__leg_minangle)
+            self.__stretchangle = self.__leg_minangle
+        self.__currentangle = self.__stretchangle
 
     def setswing(self):
+        """ DEPRICATED - Use Swing instead"""
+        print("This function is depricated use swing instead")
+
+    def swing(self):
         """
         Sets the limb to its swing position, which is 45 degrees - halfway
         between the body and stretch position.
         """
         if not self.invert:
-            swing_angle = (self.leg_minangle / 2) + self.leg_minangle
-            self.setangle(swing_angle)
+            swing_angle = (self.__leg_minangle / 2) + self.__leg_minangle
+            self.angle(swing_angle)
         else:
-            swing_angle = (self.leg_maxangle - self.leg_minangle) / 2
-            self.setangle(swing_angle)
-        self.swingangle = swing_angle
-        self.currentangle = self.swingangle
+            swing_angle = (self.__leg_maxangle - self.__leg_minangle) / 2
+            self.angle(swing_angle)
+        self.__swingangle = swing_angle
+        self.__currentangle = self.__swingangle
 
     def up(self):
         """
         raises the limb to its minimum angle
         """
         if not self.invert:
-            self.setangle(self.leg_minangle)
+            self.angle(self.__leg_minangle)
         else:
-            self.setangle(self.leg_maxangle)
+            self.angle(self.__leg_maxangle)
 
     def down(self):
         """
         lowers the limb to its maximum angle
         """
         if not self.invert:
-            self.setangle(self.leg_maxangle)
+            self.angle(self.__leg_maxangle)
         else:
-            self.setangle(self.leg_minangle)
+            self.angle(self.__leg_minangle)
 
     def middle(self):
         """
         moves the limb to half way between up and down.
         """
-        self.setangle(self.leg_maxangle - self.leg_minangle)
+        self.angle(self.__leg_maxangle - self.__leg_minangle)
 
     def show(self):
         """
         used for debugging - shows the servo driver channel number and the limb name
         """
-        print(self.channel)
+        print(self.__channel)
         print(self.name)
 
-    def setangle(self, angle):
+    def setangle(self,angle):
+        """
+        DEPRICATED METHOD - USE .angle
+        """
+        print("This method is depricated - use .angle instead")
+
+    def angle(self, angle):
         """
         Works out the value of the angle by mapping the leg_min and leg_max to
         between 0 and 180 degrees, then moves the limb to that position
@@ -234,22 +269,22 @@ class Leg(object):
         pulse = 0
 
         if angle >= 0 and angle <= 180:
-            self.leg_angle = angle
+            self.__leg_angle = angle
             # Check the angle is within the boundaries for this limb
-            if angle >= self.leg_minangle and angle <= self.leg_maxangle:
-                mapmax = self.leg_max - self.leg_min
+            if angle >= self.__leg_minangle and angle <= self.__leg_maxangle:
+                mapmax = self.__leg_max - self.__leg_min
                 percentage = (float(angle) / 180) * 100
                 pulse = int(((float(mapmax) / 100) *
-                             float(percentage)) + self.leg_min)
+                             float(percentage)) + self.__leg_min)
 
                 # send the servo the pulse, to set the angle
                 try:
-                    if do_no_use_PCA_driver is False:
-                        PWM.set_pwm(self.channel, self.channel, pulse)
+                    if DO_NOT_USE_PCA_DRIVER is False:
+                        PWM.set_pwm(self.__channel, self.__channel, pulse)
                 except RuntimeError as error:
                     logging.warning("Failed to set the pwm frequency - \
                     did the servo driver initialize correctly?")
-                self.currentangle = angle
+                self.__currentangle = angle
                 return True
 
 
@@ -264,18 +299,18 @@ class Leg(object):
 
     def untick(self):
         """ Used to walk backwards """
-        if self.name == "right_leg_back" or self.name == "right_leg_front":
-            if self.currentangle <= self.leg_maxangle:
-                self.currentangle += 2
+        if self.__name == "right_leg_back" or self.__name == "right_leg_front":
+            if self.__currentangle <= self.__leg_maxangle:
+                self.__currentangle += 2
                 # print self.name, "setting angle to ", self.currentAngle
-                self.setangle(self.currentangle)
+                self.angle(self.__currentangle)
                 return False
             return True
-        elif self.name == "left_leg_back" or self.name == "left_leg_front":
-            if self.currentangle >= self.leg_minangle:
-                self.currentangle -= 2
+        elif self.__name == "left_leg_back" or self.__name == "left_leg_front":
+            if self.__currentangle >= self.__leg_minangle:
+                self.__currentangle -= 2
                 # print self.name, "setting angle to ", self.currentAngle
-                self.setangle(self.currentangle)
+                self.angle(self.__currentangle)
                 return False
             return True
         return True
@@ -285,29 +320,39 @@ class Leg(object):
         Each tick received changes the current angle of the limb, unless an
         limit is reached, which then returns a true value
         """
-        if self.name == "left_leg_front" or self.name == "left_leg_back":
-            if self.currentangle <= self.leg_maxangle:
-                self.currentangle += 2
+        if self.__name == "left_leg_front" or self.__name == "left_leg_back":
+            if self.__currentangle <= self.__leg_maxangle:
+                self.__currentangle += 2
                 # print self.name, "setting angle to ", self.currentAngle
-                self.setangle(self.currentangle)
+                self.angle(self.__currentangle)
                 return False
             return True
-        elif self.name == "right_leg_front" or self.name == "right_leg_back":
-            if self.currentangle >= self.leg_minangle:
-                self.currentangle -= 2
+        elif self.__name == "right_leg_front" or self.__name == "right_leg_back":
+            if self.__currentangle >= self.__leg_minangle:
+                self.__currentangle -= 2
                 # print self.name, "setting angle to ", self.currentAngle
-                self.setangle(self.currentangle)
+                self.angle(self.__currentangle)
                 return False
             return True
         return True
 
+    @property
+    def name(self):
+        """ gets the Robot name """
+        return self.__name
+
+    @name.setter
+    def name(self, name):
+        """ Sets the Robot name """
+        self.__name = name
+
 class SmarsRobot(object):
     """
     This is used to model the robot, its legs and its sensors
     """
     def __init__(self):
         try:
-            if do_no_use_PCA_driver is False:
+            if DO_NOT_USE_PCA_DRIVER is False:
                 pwm = Adafruit_PCA9685.PCA9685()
                 pwm.set_pwm_freq(60)
         except RuntimeError as error:
@@ -319,59 +364,76 @@ class SmarsRobot(object):
     type = ['wheel', 'quad']
 
     # setup two arrays, one for legs, and one for feet
-    legs = []
-    feet = []
-    name = ""  # the friendly name for the robot - used in console messages.
+    __legs = []
+    __feet = []
+    __name = ""  # the friendly name for the robot - used in console messages.
 
     # add each foot to the feet array
-    feet.append(Leg(name='left_foot_front', channel=1,
+    __feet.append(Leg(name='left_foot_front', channel=1,
                     leg_minangle=50, leg_maxangle=150, invert=False))
-    feet.append(Leg(name='left_foot_back', channel=3,
+    __feet.append(Leg(name='left_foot_back', channel=3,
                     leg_minangle=50, leg_maxangle=150, invert=True))
-    feet.append(Leg(name='right_foot_front', channel=7,
+    __feet.append(Leg(name='right_foot_front', channel=7,
                     leg_minangle=50, leg_maxangle=150, invert=True))
-    feet.append(Leg(name='right_foot_back', channel=5,
+    __feet.append(Leg(name='right_foot_back', channel=5,
                     leg_minangle=50, leg_maxangle=150, invert=False))
 
     # add each leg to the legs array
-    legs.append(Leg(name='left_leg_front', channel=0,
+    __legs.append(Leg(name='left_leg_front', channel=0,
                     leg_minangle=9, leg_maxangle=90, invert=True))
-    legs.append(Leg(name='left_leg_back', channel=2,
+    __legs.append(Leg(name='left_leg_back', channel=2,
                     leg_minangle=90, leg_maxangle=180, invert=False))
-    legs.append(Leg(name='right_leg_front', channel=6,
+    __legs.append(Leg(name='right_leg_front', channel=6,
                     leg_minangle=90, leg_maxangle=180, invert=False))
-    legs.append(Leg(name='right_leg_back', channel=4,
+    __legs.append(Leg(name='right_leg_back', channel=4,
                     leg_minangle=9, leg_maxangle=90, invert=True))
     # print "number of legs", len(legs)
 
-    def setname(self, name):
+    @property
+    def name(self):
+        """
+        gets the robots name
+        """
+        return self.__name
+
+    @name.setter
+    def name(self, name):
         """
         Sets the robots name, used for displaying console messages.
         """
-        self.name = name
+        self.__name = name
+
+        # TODO: add a logging level to output messages
         print("***", name, "Online ***")
 
+    def setname(self,name):
+        """
+        Depricated - use the .name property
+        """
+        print("Depricated - use the .name property")
+        self.name = name
+
     def leg_reset(self):
         """
         used to reset all the legs
         """
-        for limb in self.legs:
-            limb.setdefault()
+        for limb in self.__legs:
+            limb.default()
 
     def middle(self):
         """
         used to position all the legs into the middle position
         """
         print("received middle command")
-        for limb in self.legs:
+        for limb in self.__legs:
             limb.middle()
 
     def sit(self):
         """
         used to sit the robot down
         """
-        print(self.name, "sitting Down.")
-        for limb in self.feet:
+        print(self.__name, "sitting Down.")
+        for limb in self.__feet:
             limb.down()
 
     def stand(self):
@@ -379,19 +441,19 @@ class SmarsRobot(object):
         used to stand the robot up
         """
         print(self.name, "standing up.")
-        for limb in self.feet:
+        for limb in self.__feet:
             limb.up()
 
-    def setswing(self):
+    def swing(self):
         """
         Moves the limb to the swing position
         """
         for limb in range(0, 4):
-            self.feet[limb].down()
+            self.__feet[limb].down()
             time.sleep(SLEEP_COUNT)
-            self.legs[limb].setswing()
+            self.__legs[limb].setswing()
             time.sleep(SLEEP_COUNT)
-            self.feet[limb].up()
+            self.__feet[limb].up()
             time.sleep(SLEEP_COUNT)
 
     def turnright(self):
@@ -404,17 +466,17 @@ class SmarsRobot(object):
         print(self.name, "Turning Right.")
 
         # move legs one at a time back to swing position
-        self.setswing()
+        self.swing()
 
         # twist body
-        self.legs[chan.RIGHT_LEG_FRONT].setstretch()
-        self.legs[chan.RIGHT_LEG_BACK].setbody()
-        self.legs[chan.LEFT_LEG_FRONT].setbody()
-        self.legs[chan.LEFT_LEG_BACK].setstretch()
+        self.__legs[chan.RIGHT_LEG_FRONT].stretch()
+        self.__legs[chan.RIGHT_LEG_BACK].body()
+        self.__legs[chan.LEFT_LEG_FRONT].body()
+        self.__legs[chan.LEFT_LEG_BACK].stretch()
         time.sleep(SLEEP_COUNT)
 
         # move legs one at a time back to swing position
-        self.setswing()
+        self.swing()
 
     def turnleft(self):
         """
@@ -424,17 +486,17 @@ class SmarsRobot(object):
         print(self.name, "Turning left.")
 
         # move legs one at a time back to swing position
-        self.setswing()
+        self.swing()
 
         # twist body
-        self.legs[chan.LEFT_LEG_FRONT].setstretch()
-        self.legs[chan.LEFT_LEG_BACK].setbody()
-        self.legs[chan.RIGHT_LEG_FRONT].setbody()
-        self.legs[chan.RIGHT_LEG_BACK].setstretch()
+        self.__legs[chan.LEFT_LEG_FRONT].stretch()
+        self.__legs[chan.LEFT_LEG_BACK].body()
+        self.__legs[chan.RIGHT_LEG_FRONT].body()
+        self.__legs[chan.RIGHT_LEG_BACK].stretch()
         time.sleep(SLEEP_COUNT)
 
         # move legs one at a time back to swing position
-        self.setswing()
+        self.swing()
 
     def walkforward(self, steps):
         """
@@ -446,10 +508,10 @@ class SmarsRobot(object):
 
         # set the legs to the correct position for walking.
         self.sit()
-        self.legs[chan.LEFT_LEG_FRONT].setbody()
-        self.legs[chan.LEFT_LEG_BACK].setbody()
-        self.legs[chan.RIGHT_LEG_FRONT].setswing()
-        self.legs[chan.RIGHT_LEG_BACK].setswing()
+        self.__legs[chan.LEFT_LEG_FRONT].setbody()
+        self.__legs[chan.LEFT_LEG_BACK].setbody()
+        self.__legs[chan.RIGHT_LEG_FRONT].setswing()
+        self.__legs[chan.RIGHT_LEG_BACK].setswing()
         self.stand()
 
         # the walking cycle, loops for the number of steps provided.
@@ -458,25 +520,25 @@ class SmarsRobot(object):
             current_step += 1
 
             for n in range(0, 4):
-                if not self.legs[n].tick():
-                    self.legs[n].tick()
+                if not self.__legs[n].tick():
+                    self.__legs[n].tick()
                 else:
-                    self.feet[n].down()
+                    self.__feet[n].down()
                     time.sleep(SLEEP_COUNT)
 
                     # change this to left and right legs, rather than invert or not invert
-                    if not self.legs[n].invert:
-                        if self.legs[n].name == "right_leg_front":
-                            self.legs[n].setstretch()
+                    if not self.__legs[n].invert:
+                        if self.__legs[n].name == "right_leg_front":
+                            self.__legs[n].stretch()
                         else:
-                            self.legs[n].setbody()
-                    elif self.legs[n].invert:
-                        if self.legs[n].name == "right_leg_back":
-                            self.legs[n].setbody()
+                            self.__legs[n].body()
+                    elif self.__legs[n].invert:
+                        if self.__legs[n].name == "right_leg_back":
+                            self.__legs[n].body()
                         else:
-                            self.legs[n].setstretch()
+                            self.__legs[n].stretch()
                     time.sleep(SLEEP_COUNT)
-                    self.feet[n].up()
+                    self.__feet[n].up()
                     time.sleep(SLEEP_COUNT)
 
     def walkbackward(self, steps):
@@ -487,10 +549,10 @@ class SmarsRobot(object):
 
         # set the legs to the correct position for walking.
         self.sit()
-        self.legs[chan.LEFT_LEG_FRONT].setbody()
-        self.legs[chan.LEFT_LEG_BACK].setbody()
-        self.legs[chan.RIGHT_LEG_FRONT].setswing()
-        self.legs[chan.RIGHT_LEG_BACK].setswing()
+        self.__legs[chan.LEFT_LEG_FRONT].body()
+        self.__legs[chan.LEFT_LEG_BACK].body()
+        self.__legs[chan.RIGHT_LEG_FRONT].swing()
+        self.__legs[chan.RIGHT_LEG_BACK].swing()
         self.stand()
 
         # the walking cycle, loops for the number of steps provided.
@@ -498,27 +560,27 @@ class SmarsRobot(object):
         while current_step < steps:
             current_step += 1
             for n in range(0, 4):
-                if not self.legs[n].untick():
+                if not self.__legs[n].untick():
                     # print self.name, "walking, step", currentStep, "of", steps
-                    self.legs[n].untick()
+                    self.__legs[n].untick()
                 else:
                     # print "moving leg:", self.legs[n].name
-                    self.feet[n].down()
+                    self.__feet[n].down()
                     time.sleep(SLEEP_COUNT)
 
                     # change this to left and right legs, rather than invert or not invert
-                    if not self.legs[n].invert:
-                        if self.legs[n].name == "left_leg_back":
-                            self.legs[n].setstretch()
+                    if not self.__legs[n].invert:
+                        if self.__legs[n].name == "left_leg_back":
+                            self.__legs[n].stretch()
                         else:
-                            self.legs[n].setbody()
-                    elif self.legs[n].invert:
-                        if self.legs[n].name == "left_leg_front":
-                            self.legs[n].setbody()
+                            self.__legs[n].body()
+                    elif self.__legs[n].invert:
+                        if self.__legs[n].name == "left_leg_front":
+                            self.__legs[n].body()
                         else:
-                            self.legs[n].setstretch()
+                            self.__legs[n].stretch()
                     time.sleep(SLEEP_COUNT)
-                    self.feet[n].up()
+                    self.__feet[n].up()
                     time.sleep(SLEEP_COUNT)
 
     def clap(self, clap_count):
@@ -529,11 +591,11 @@ class SmarsRobot(object):
         # self.feet[left_foot_front].up()
         # self.feet[right_foot_front].up()
         for _ in range(0, clap_count):
-            self.legs[chan.LEFT_LEG_FRONT].setbody()
-            self.legs[chan.RIGHT_LEG_FRONT].setbody()
+            self.__legs[chan.LEFT_LEG_FRONT].body()
+            self.__legs[chan.RIGHT_LEG_FRONT].body()
             time.sleep(SLEEP_COUNT * 2)
-            self.legs[chan.LEFT_LEG_FRONT].setstretch()
-            self.legs[chan.RIGHT_LEG_FRONT].setstretch()
+            self.__legs[chan.LEFT_LEG_FRONT].stretch()
+            self.__legs[chan.RIGHT_LEG_FRONT].stretch()
             time.sleep(SLEEP_COUNT * 2)
         self.stand()
 
@@ -543,16 +605,16 @@ class SmarsRobot(object):
         chan = Channel()
 
         self.sit()
-        self.legs[chan.LEFT_FOOT_BACK].up()
-        self.legs[chan.RIGHT_FOOT_BACK].up()
+        self.__legs[chan.LEFT_FOOT_BACK].up()
+        self.__legs[chan.RIGHT_FOOT_BACK].up()
         time.sleep(SLEEP_COUNT * 5)
 
         for _ in range(0, wiggle_count):
-            self.legs[chan.LEFT_LEG_BACK].setbody()
-            self.legs[chan.RIGHT_LEG_BACK].setstretch()
+            self.__legs[chan.LEFT_LEG_BACK].body()
+            self.__legs[chan.RIGHT_LEG_BACK].stretch()
             time.sleep(SLEEP_COUNT * 5)
-            self.legs[chan.LEFT_LEG_BACK].setstretch()
-            self.legs[chan.RIGHT_LEG_BACK].setbody()
+            self.__legs[chan.LEFT_LEG_BACK].stretch()
+            self.__legs[chan.RIGHT_LEG_BACK].body()
             time.sleep(SLEEP_COUNT * 5)
         self.stand()
 
@@ -560,121 +622,47 @@ class SmarsRobot(object):
         """ returns a list of limbs and measurements """
         telemetry = []
         chan = Channel()
-        telemetry.append(["left_leg_front", self.legs[chan.LEFT_LEG_FRONT].leg_angle])
-        telemetry.append(["right_leg_front", self.legs[chan.RIGHT_LEG_FRONT].leg_angle])
-        telemetry.append(["left_leg_back", self.legs[chan.LEFT_LEG_BACK].leg_angle])
-        telemetry.append(["right_leg_back", self.legs[chan.RIGHT_LEG_BACK].leg_angle])
-        telemetry.append(["left_foot_front", self.legs[chan.LEFT_FOOT_FRONT].leg_angle])
-        telemetry.append(["right_foot_front", self.legs[chan.RIGHT_FOOT_FRONT].leg_angle])
-        telemetry.append(["left_foot_back", self.legs[chan.LEFT_FOOT_BACK].leg_angle])
-        telemetry.append(["right_foot_back", self.legs[chan.RIGHT_FOOT_BACK].leg_angle])
+        telemetry.append(["left_leg_front", self.__legs[chan.LEFT_LEG_FRONT].leg_angle])
+        telemetry.append(["right_leg_front", self.__legs[chan.RIGHT_LEG_FRONT].leg_angle])
+        telemetry.append(["left_leg_back", self.__legs[chan.LEFT_LEG_BACK].leg_angle])
+        telemetry.append(["right_leg_back", self.__legs[chan.RIGHT_LEG_BACK].leg_angle])
+        telemetry.append(["left_foot_front", self.__legs[chan.LEFT_FOOT_FRONT].leg_angle])
+        telemetry.append(["right_foot_front", self.__legs[chan.RIGHT_FOOT_FRONT].leg_angle])
+        telemetry.append(["left_foot_back", self.__legs[chan.LEFT_FOOT_BACK].leg_angle])
+        telemetry.append(["right_foot_back", self.__legs[chan.RIGHT_FOOT_BACK].leg_angle])
         return telemetry
 
-class SMARSColor(object):
-    """ Some standard console colors for use with terminal display output """
-
-    # Foreground Colours
-    WHITE = u'\001b[30m'
-    RED = u'\001b[31m'
-    GREEN = u'\001b[32m'
-    YELLOW = u'\001b[33m'
-    BLUE = u'\001b[34m'
-    MAGENTA = u'\001b[35m'
-    CYAN = u'\001b[36m'
-    BLACK = u'\001b[30m'
-    DARKPINK = u'\033[95m'
-    PINK = u'\033[94m'
-    RESET = u'\033[0m'
-    NORMAL = u'\033[0m'
-
-    # Bright Colours
-    BRIGHTWHITE = u'\001b[30;1m'
-    BRIGHTRED = u'\001b[31;1m'
-    BRIGHTGREEN = u'\001b[32;1m'
-    BRIGHTYELLOW = u'\001b[33;1m'
-    BRIGHTBLUE = u'\001b[34;1m'
-    BRIGHTMAGENTA = u'\001b[35;1m'
-    BRIGHTCYAN = u'\001b[36m;1m'
-    DARKGRAY = u'\u001b[30;1m'
-    BRIGHTPINK = u'\033[94m;1m'
-
-    # Decoration
-    REVERSED = u'\u001b[7m'
-    BOLD = u'\033[1m'
-    UNDERLINE = u'\033[4m'
-
-    # Background Colours
-    BG_BLUE = u'\033[44m'
-    BG_BLACK = u'\u001b[40m'
-    BG_RED = u'\u001b[41m'
-    BG_GREEN = u'\u001b[42m'
-    BG_YELLOW = u'\u001b[43m'
-    BG_MAGENTA = u'\u001b[45m'
-    BG_CYAN = u'\u001b[46m'
-    BG_WHITE = u'\u001b[47m'
-
-    # Clear screen or line
-    # clears the screen from the cursor
-    CLEAR_SCREEN_FROM_CURSOR = u'\u001b[0J'
-
-    # Clears the screen from the beginning of the screen to the cursor
-    CLEAR_SCREEN_TO_CURSOR = u'\u001b[1J'
-
-    # Clears the screen
-    CLEAR_SCREEN = u'\u001b[2J'
-
-    CLEAR_LINE = u'\u001b[2K'
-    CLEAR_LINE_FROM_CURSOR = u'\u001b[0K'
-    CLEAR_LINE_TO_CURSOR = u'\u001b[1K'
-
-    # Move cursor
-    @classmethod
-    def cursor_left(cls, no_of_chars):
-        """ moves the cursor left """
-        print(u'\u001b[' + str(no_of_chars) + 'D')
-
-    @classmethod
-    def cursor_right(cls, no_of_chars):
-        """ moves the cursor right """
-        print(u'\u001b[' + str(no_of_chars) + 'C')
-
-    @classmethod
-    def cursor_up(cls, no_of_chars):
-        """ moves the cursor up"""
-        print(u'\u001b[' + str(no_of_chars) + 'A')
-
-    @classmethod
-    def cursor_down(cls, no_of_chars):
-        """ moves the cursor down """
-        print(u'\u001b[' + str(no_of_chars) + 'B')
-
-    @classmethod
-    def set_position(cls, x_pos, y_pos):
-        """ sets the cursor position """
-        position = u'\u001b[' + str(x_pos) + ';' + str(y_pos) + 'H'
-        print(position)
-
-
 class CommandHistory(object):
     """ models the command history object """
 
-    history = []
+    # Private property History
+    __history = []
 
     def __init__(self):
-        self.history.append("*** new history ***")
+        self.__history.append("*** new history ***")
 
     def append(self, command):
         """ adds a command to the command history """
-        self.history.append(command)
+        self.__history.append(command)
 
     def clear(self):
         """ clears the command history """
-        self.history = []
+        self.__history = []
+
+    @property
+    def history(self):
+        """ gets all command history """
+        return self.__history
 
     def get_history(self):
-        """ get all command history """
-        return self.history
+        """ DEPRICATED - use .history property"""
+        print("This function is depricated - use .history property")
+
+    @property
+    def last_ten(self):
+        """ get last 10 command history """
+        return self.__history[-10:]
 
     def get_last_ten(self):
-        """ get last 10 command history """
-        return self.history[-10:]
+        """ DEPRICATED - Use .last_ten property """
+        print("This function is deprecated - use .last_ten property instead")
